import React, {useState, useEffect} from "react";
import {Button, Col, Form, InputGroup, Modal, Row} from "react-bootstrap";
import {Stepper, Step} from "react-form-stepper";
import {connect, useDispatch} from "react-redux";
import userDataAccess from "dataAccess/userDataAccess";
import SliderDataAccess from "dataAccess/sliderDataAccess";
import { useHistory } from "react-router-dom"

import {toast} from "react-toastify";
import {StepStyleDTO} from "react-form-stepper/dist/components/Step/StepTypes";
import SpinnerLocal from "../../components/spinner";

const SellOnGenx = (props: any) => {
    // const [name, setName] = useState(null);

    let history = useHistory()
    const previousAddress = props.initialAddress;
    const [goSteps, setGoSteps] = useState(0);

    const [selectedCity, setSelectedCity] = useState(0);
    const [cityList, setCityList] = useState([]);

    useEffect(() => {
        userDataAccess
            .getCityList()
            .then((data) => {
                setCityList(data);
            })
            .catch((error) => {
                " ";
            });
    }, [selectedCity]);

    const handleCityChange = (e) => {
        setSelectedCity(e.target.value);
    };

    // step1
    const [storeName, setStoreName] = useState(null);
    const [state, setState] = useState(null);
    const [city, setCity] = useState(null);
    const [zipcode, setZipcode] = useState(null);
    const [trandeLin, settrandeLin] = useState(null);
    const [date, setDate] = useState(null);
    const [vatReg, setVatReg] = useState(null);

    // step2
    const [tradeLicenseImg, setTradeLicenseImg] = useState(null);
    const [vatImg, setVatImg] = useState(null);
    const handleTradeLicenseImage = (e) => {
        // console.log(URL.createObjectURL(e.target.files[0]));
        setTradeLicenseImg(e.target.files[0]);
    };
    const handleVatImg = (e) => {
        setVatImg(e.target.files[0]);
    };

    // step3
    const [bankName, setBankName] = useState(null);
    const [bankAccount, setBankAccount] = useState(null);
    const [branch, setBranch] = useState(null);
    const [accountName, setAccountName] = useState(null);

    // step4
    const [name, setName] = useState(null);
    const [phone, setPhone] = useState(null);
    const [email, setEmail] = useState(null);
    const [password, setPassword] = useState(null);

    const [loading, setLoading] = useState(false);

    const handleStep = () => {
        setLoading(true)
        SliderDataAccess.submitRegisterValue(
            storeName,
            selectedCity,
            state,
            city,
            zipcode,
            trandeLin,
            date,
            vatReg,
            vatImg,
            tradeLicenseImg,
            bankName,
            accountName,
            branch,
            bankAccount,
            name,
            email,
            phone,
            password
        ).then((data) => {
            setLoading(false)
            if (data.status === true) {
                toast.success(data.message);
                setStoreName(null);
                setSelectedCity(null);
                setState(null);
                setCity(null);
                setZipcode(null);
                settrandeLin(null);
                setDate(null);
                setVatReg(null);
                setVatImg(null)
                setTradeLicenseImg(null);
                setBankName(null);
                setAccountName(null);
                setBranch(null);
                setBankAccount(null);
                setName(null);
                setPhone(null);
                setEmail(null);
                setPassword(null);
                setGoSteps(0);
                history.push("/")
            } else {
                setGoSteps(0);
                toast.error(data.message);
            }
        });

    };

    let style: StepStyleDTO = {
        activeTextColor: '#fff',
        borderRadius: '50%',
        circleFontSize: '1rem',
        completedBgColor: '#dd322b',
        completedTextColor: '#fff',
        fontWeight: 500,
        inactiveBgColor: '#aaa',
        inactiveTextColor: '#fff',
        labelFontSize: '0.875rem',
        size: '2em',
        activeBgColor: '#253157',
    }

    if (loading) {
        return <SpinnerLocal height="75vh"/>
    }

    return (
        <div className="user-profile-top">
            <div className="create-account-container contact-us-bottom profile-bottom">
                <Stepper
                    activeStep={goSteps} styleConfig={style}>
                    <Step onClick={() => setGoSteps(0)}/>
                    <Step onClick={() => setGoSteps(1)}/>
                    <Step onClick={() => setGoSteps(2)}/>
                    <Step onClick={() => setGoSteps(3)}/>
                </Stepper>
                <Row>
                    <Col className="sideNav">
                        <Row className="order-summary">
                            <Col
                                xl={12}
                                lg={12}
                                md={12}
                                sm={12}
                                xs={12}
                                className="first-section"
                            >
                                <div>
                                    <span className="header"> Sale on Genx Registration </span>
                                </div>
                            </Col>
                            <hr style={{width: "100%"}}/>
                            <Col
                                xl={12}
                                lg={12}
                                md={12}
                                sm={12}
                                xs={12}
                                className="second-section"
                            >
                                {goSteps == 0 && (
                                    <form>
                                        <Form.Group>
                                            <Row>
                                                <Form.Label
                                                    column="lg"
                                                    lg={2}
                                                    className="shipping-addr-form-label"
                                                >
                                                    Store name
                                                </Form.Label>
                                                <Col xl={10} lg={10} md={12} sm={12} xs={12}>
                                                    <Form.Control
                                                        onChange={(e) => setStoreName(e.target.value)}
                                                        type="text"
                                                        placeholder="Store Name"
                                                        required
                                                        value={storeName}
                                                    />
                                                </Col>
                                            </Row>
                                        </Form.Group>
                                        <Form.Group>
                                            <Row>
                                                <Form.Label
                                                    column="lg"
                                                    lg={2}
                                                    className="shipping-addr-form-label"
                                                >
                                                    Country
                                                </Form.Label>
                                                <Col xl={10} lg={10} md={12} sm={12} xs={12}>
                                                    <select
                                                        onChange={handleCityChange}
                                                        name="city"
                                                        className="select-city-options"
                                                        value={selectedCity}
                                                    >
                                                        <option>(Select Country)</option>
                                                        {cityList.map((city, index) => (
                                                            <option value={city.id} key={index}>
                                                                {" "}
                                                                {city.area}{" "}
                                                            </option>
                                                        ))}
                                                    </select>
                                                </Col>
                                            </Row>
                                        </Form.Group>
                                        <Form.Group>
                                            <Row>
                                                <Form.Label
                                                    column="lg"
                                                    lg={2}
                                                    className="shipping-addr-form-label"
                                                >
                                                    State
                                                </Form.Label>
                                                <Col xl={10} lg={10} md={12} sm={12} xs={12}>
                                                    <Form.Control
                                                        type="text"
                                                        onChange={(e) => setState(e.target.value)}
                                                        placeholder="State"
                                                        required
                                                        value={state}
                                                    />
                                                </Col>
                                            </Row>
                                        </Form.Group>
                                        <Form.Group>
                                            <Row>
                                                <Form.Label
                                                    column="lg"
                                                    lg={2}
                                                    className="shipping-addr-form-label"
                                                >
                                                    City
                                                </Form.Label>
                                                <Col xl={10} lg={10} md={12} sm={12} xs={12}>
                                                    <Form.Control
                                                        type="text"
                                                        onChange={(e) => setCity(e.target.value)}
                                                        placeholder="City"
                                                        required
                                                        value={city}
                                                    />
                                                </Col>
                                            </Row>
                                        </Form.Group>
                                        <Form.Group>
                                            <Row>
                                                <Form.Label
                                                    column="lg"
                                                    lg={2}
                                                    className="shipping-addr-form-label"
                                                >
                                                    Zipcode
                                                </Form.Label>
                                                <Col xl={10} lg={10} md={12} sm={12} xs={12}>
                                                    <Form.Control
                                                        type="text"
                                                        onChange={(e) => setZipcode(e.target.value)}
                                                        placeholder="Zipcode"
                                                        required
                                                        value={zipcode}
                                                    />
                                                </Col>
                                            </Row>
                                        </Form.Group>
                                        <Form.Group>
                                            <Row>
                                                <Form.Label
                                                    column="lg"
                                                    lg={2}
                                                    className="shipping-addr-form-label"
                                                >
                                                    Trade License No
                                                </Form.Label>
                                                <Col xl={10} lg={10} md={12} sm={12} xs={12}>
                                                    <Form.Control
                                                        type="text"
                                                        onChange={(e) => settrandeLin(e.target.value)}
                                                        placeholder="Trade License No..."
                                                        required
                                                        value={trandeLin}
                                                    />
                                                </Col>
                                            </Row>
                                        </Form.Group>
                                        <Form.Group>
                                            <Row>
                                                <Form.Label
                                                    column="lg"
                                                    lg={2}
                                                    className="shipping-addr-form-label"
                                                >
                                                    Date
                                                </Form.Label>
                                                <Col xl={10} lg={10} md={12} sm={12} xs={12}>
                                                    <Form.Control
                                                        type="date"
                                                        onChange={(e) => setDate(e.target.value)}
                                                        placeholder="mm/dd/yyyy"
                                                        required
                                                        value={date}
                                                    />
                                                </Col>
                                            </Row>
                                        </Form.Group>
                                        <Form.Group>
                                            <Row>
                                                <Form.Label
                                                    column="lg"
                                                    lg={2}
                                                    className="shipping-addr-form-label"
                                                >
                                                    Vat Registration No
                                                </Form.Label>
                                                <Col xl={10} lg={10} md={12} sm={12} xs={12}>
                                                    <Form.Control
                                                        type="text"
                                                        onChange={(e) => setVatReg(e.target.value)}
                                                        placeholder="Vat Registration No."
                                                        required
                                                        value={vatReg}
                                                    />
                                                </Col>
                                            </Row>
                                        </Form.Group>
                                        <hr style={{width: "100%"}}/>
                                        <Col
                                            xl={12}
                                            lg={12}
                                            md={12}
                                            sm={12}
                                            xs={12}
                                            style={{textAlign: "right"}}
                                        >
                                            {storeName !== null &&
                                            city !== null &&
                                            zipcode !== null &&
                                            state !== null &&
                                            date !== null &&
                                            trandeLin !== null &&
                                            vatReg !== null ? (
                                                <Button
                                                    type="submit"
                                                    onClick={() => setGoSteps(1)}
                                                    className="proceed-shipping-btn"
                                                    style={{backgroundColor: "#e62127"}}
                                                >
                                                    Go Next
                                                </Button>
                                            ) : (
                                                <Button
                                                    type="submit"
                                                    onClick={() => setGoSteps(1)}
                                                    className="proceed-shipping-btn"
                                                    disabled
                                                    style={{backgroundColor: "#e62127"}}
                                                >
                                                    Go Next
                                                </Button>
                                            )}
                                        </Col>
                                    </form>
                                )}
                                {goSteps === 1 && (
                                    <form>
                                        <h2>Company Documents :</h2>
                                        <Form.Group>
                                            <Row>
                                                <Form.Label
                                                    column="lg"
                                                    lg={4}
                                                    className="shipping-addr-form-label"
                                                >
                                                    Trade License Documents <span style={{
                                                    fontSize: 14,
                                                    color: '#dd322b'
                                                }}>(Only PDF file are allowed)</span>
                                                </Form.Label>
                                                <Col xl={8} lg={9} md={12} sm={12} xs={12}>
                                                    <Form.Control
                                                        onChange={handleTradeLicenseImage}
                                                        type="file"
                                                        className="mt-2"
                                                        accept="application/pdf"
                                                        required
                                                        // value={tradeLicenseImg}
                                                    />
                                                </Col>
                                            </Row>
                                        </Form.Group>
                                        <Form.Group>
                                            <Row>
                                                <Form.Label
                                                    column="lg"
                                                    lg={4}
                                                    className="shipping-addr-form-label"
                                                >
                                                    Vat Certificate Documents <span style={{
                                                    fontSize: 14,
                                                    color: '#dd322b'
                                                }}>(Only PDF file are allowed)</span>
                                                </Form.Label>
                                                <Col xl={8} lg={9} md={12} sm={12} xs={12}>
                                                    <Form.Control
                                                        type="file"
                                                        onChange={handleVatImg}
                                                        className="mt-2"
                                                        accept="application/pdf"
                                                        required
                                                        // value={vatImg}
                                                    />
                                                </Col>
                                            </Row>
                                        </Form.Group>
                                        <hr style={{width: "100%"}}/>
                                        <Col
                                            xl={12}
                                            lg={12}
                                            md={12}
                                            sm={12}
                                            xs={12}
                                            style={{textAlign: "right"}}
                                        >
                                            <div>
                                                <Button
                                                    onClick={() => setGoSteps(0)}
                                                    className="proceed-shipping-btn ml-3"
                                                    style={{backgroundColor: "#e62127"}}
                                                >
                                                    Previous
                                                </Button>
                                                {vatImg !== null &&
                                                tradeLicenseImg !== null
                                                    ? (
                                                        <Button
                                                            type="submit"
                                                            onClick={() => setGoSteps(2)}
                                                            className="proceed-shipping-btn ml-3"
                                                            style={{backgroundColor: "#e62127"}}
                                                        >
                                                            Go Next
                                                        </Button>
                                                    ) : (
                                                        <Button
                                                            type="submit"
                                                            onClick={() => setGoSteps(2)}
                                                            className="proceed-shipping-btn ml-3"
                                                            disabled
                                                            style={{backgroundColor: "#e62127"}}
                                                        >
                                                            Go Next
                                                        </Button>
                                                    )}
                                            </div>
                                        </Col>
                                    </form>
                                )}
                                {goSteps == 2 && (
                                    <>
                                        <h2>Bank Detail :</h2>
                                        <form>
                                            <Form.Group>
                                                <Row>
                                                    <Form.Label
                                                        column="lg"
                                                        lg={2}
                                                        className="shipping-addr-form-label"
                                                    >
                                                        Bank Name
                                                    </Form.Label>
                                                    <Col xl={10} lg={10} md={12} sm={12} xs={12}>
                                                        <Form.Control
                                                            type="text"
                                                            onChange={(e) => setBankName(e.target.value)}
                                                            placeholder="Bank Name"
                                                            required
                                                            value={bankName}
                                                        />
                                                    </Col>
                                                </Row>
                                            </Form.Group>
                                            <Form.Group>
                                                <Row>
                                                    <Form.Label
                                                        column="lg"
                                                        lg={2}
                                                        className="shipping-addr-form-label"
                                                    >
                                                        Account Name
                                                    </Form.Label>
                                                    <Col xl={10} lg={10} md={12} sm={12} xs={12}>
                                                        <Form.Control
                                                            type="text"
                                                            onChange={(e) => setAccountName(e.target.value)}
                                                            placeholder="Account Name"
                                                            required
                                                            value={accountName}
                                                        />
                                                    </Col>
                                                </Row>
                                            </Form.Group>
                                            <Form.Group>
                                                <Row>
                                                    <Form.Label
                                                        column="lg"
                                                        lg={2}
                                                        className="shipping-addr-form-label"
                                                    >
                                                        Branch
                                                    </Form.Label>
                                                    <Col xl={10} lg={10} md={12} sm={12} xs={12}>
                                                        <Form.Control
                                                            type="text"
                                                            onChange={(e) => setBranch(e.target.value)}
                                                            placeholder="Branch"
                                                            required
                                                            value={branch}
                                                        />
                                                    </Col>
                                                </Row>
                                            </Form.Group>
                                            <Form.Group>
                                                <Row>
                                                    <Form.Label
                                                        column="lg"
                                                        lg={2}
                                                        className="shipping-addr-form-label"
                                                    >
                                                        Account Number
                                                    </Form.Label>
                                                    <Col xl={10} lg={10} md={12} sm={12} xs={12}>
                                                        <Form.Control
                                                            type="text"
                                                            onChange={(e) => setBankAccount(e.target.value)}
                                                            placeholder="Account Number"
                                                            required
                                                            value={bankAccount}
                                                        />
                                                    </Col>
                                                </Row>
                                            </Form.Group>
                                            <hr style={{width: "100%"}}/>
                                            <Col
                                                xl={12}
                                                lg={12}
                                                md={12}
                                                sm={12}
                                                xs={12}
                                                style={{textAlign: "right"}}
                                            >
                                                {/* <div>
                          <Button
                            onClick={() => setGoSteps(1)}
                            className="proceed-shipping-btn ml-3"
                          >
                            Previous
                          </Button>
                          <Button
                            type="submit"
                            onClick={() => setGoSteps(3)}
                            className="proceed-shipping-btn ml-3"
                          >
                            Next
                          </Button>
                        </div> */}
                                                <div>
                                                    <Button
                                                        onClick={() => setGoSteps(1)}
                                                        className="proceed-shipping-btn ml-3"
                                                        style={{backgroundColor: "#e62127"}}
                                                    >
                                                        Previous
                                                    </Button>
                                                    {bankName !== null &&
                                                    accountName !== null &&
                                                    branch !== null &&
                                                    bankAccount !== null
                                                        ? (
                                                            <Button
                                                                type="submit"
                                                                onClick={() => setGoSteps(3)}
                                                                className="proceed-shipping-btn ml-3"
                                                                style={{backgroundColor: "#e62127"}}
                                                            >
                                                                Go Next
                                                            </Button>
                                                        ) : (
                                                            <Button
                                                                type="submit"
                                                                onClick={() => setGoSteps(3)}
                                                                className="proceed-shipping-btn ml-3"
                                                                disabled
                                                                style={{backgroundColor: "#e62127"}}
                                                            >
                                                                Go Next
                                                            </Button>
                                                        )}
                                                </div>
                                            </Col>
                                        </form>
                                    </>
                                )}
                                {goSteps == 3 && (
                                    <>
                                        <h2>Sign In Info</h2>
                                        <form>
                                            <Form.Group>
                                                <Row>
                                                    <Form.Label
                                                        column="lg"
                                                        lg={2}
                                                        className="shipping-addr-form-label"
                                                    >
                                                        Name
                                                    </Form.Label>
                                                    <Col xl={10} lg={10} md={12} sm={12} xs={12}>
                                                        <Form.Control
                                                            type="text"
                                                            onChange={(e) => setName(e.target.value)}
                                                            placeholder="Name"
                                                            required
                                                            value={name}
                                                        />
                                                    </Col>
                                                </Row>
                                            </Form.Group>
                                            <Form.Group>
                                                <Row>
                                                    <Form.Label
                                                        column="lg"
                                                        lg={2}
                                                        className="shipping-addr-form-label"
                                                    >
                                                        Email
                                                    </Form.Label>
                                                    <Col xl={10} lg={10} md={12} sm={12} xs={12}>
                                                        <Form.Control
                                                            type="email"
                                                            onChange={(e) => setEmail(e.target.value)}
                                                            placeholder="email"
                                                            required
                                                            value={email}
                                                        />
                                                    </Col>
                                                </Row>
                                            </Form.Group>
                                            <Form.Group>
                                                <Row>
                                                    <Form.Label
                                                        column="lg"
                                                        lg={2}
                                                        className="shipping-addr-form-label"
                                                    >
                                                        Phone
                                                    </Form.Label>
                                                    <Col xl={10} lg={10} md={12} sm={12} xs={12}>
                                                        <Form.Control
                                                            type="text"
                                                            onChange={(e) => setPhone(e.target.value)}
                                                            placeholder="phone"
                                                            required
                                                            value={phone}
                                                        />
                                                    </Col>
                                                </Row>
                                            </Form.Group>
                                            <Form.Group>
                                                <Row>
                                                    <Form.Label
                                                        column="lg"
                                                        lg={2}
                                                        className="shipping-addr-form-label"
                                                    >
                                                        Password
                                                    </Form.Label>
                                                    <Col xl={10} lg={10} md={12} sm={12} xs={12}>
                                                        <Form.Control
                                                            type="password"
                                                            onChange={(e) => setPassword(e.target.value)}
                                                            placeholder="Password"
                                                            required
                                                            value={password}
                                                        />
                                                    </Col>
                                                </Row>
                                            </Form.Group>
                                            <hr style={{width: "100%"}}/>
                                            <Col
                                                xl={12}
                                                lg={12}
                                                md={12}
                                                sm={12}
                                                xs={12}
                                                style={{textAlign: "right"}}
                                            >
                                                {/* <div>
                          <Button
                            onClick={() => setGoSteps(2)}
                            className="proceed-shipping-btn ml-3"
                          >
                            Previous
                          </Button>
                          <Button
                            onClick={handleStep}
                            className="proceed-shipping-btn ml-3"
                          >
                            Submit
                          </Button>
                        </div> */}
                                                <div>
                                                    <Button
                                                        onClick={() => setGoSteps(2)}
                                                        className="proceed-shipping-btn ml-3"
                                                        style={{backgroundColor: "#e62127"}}
                                                    >
                                                        Previous
                                                    </Button>
                                                    {name !== null &&
                                                    email !== null &&
                                                    phone !== null &&
                                                    password !== null
                                                        ? (
                                                            <Button
                                                                type="button"
                                                                onClick={handleStep}
                                                                className="proceed-shipping-btn ml-3"
                                                                style={{backgroundColor: "#e62127"}}
                                                            >
                                                                Submit
                                                            </Button>
                                                        ) : (
                                                            <Button
                                                                type="button"
                                                                className="proceed-shipping-btn ml-3"
                                                                disabled
                                                                style={{backgroundColor: "#e62127"}}
                                                            >
                                                                Submit
                                                            </Button>
                                                        )}
                                                </div>
                                            </Col>
                                        </form>
                                    </>
                                )}
                            </Col>
                        </Row>
                    </Col>
                </Row>
            </div>
        </div>
    );
};

const mapStateToProps = ({address}, ownProps) => ({
    address,
    initialValues: ownProps.initialAddress,
});

export default connect<{}, {}, any>(mapStateToProps)(SellOnGenx);
